@@ -266,21 +266,20 @@ unsigned char FPGM(bci_compute_stem_width_c) [] = {
           EIF,
         EIF,
 
-        ELSE,
-          PUSHB_1,
-            bci_round,
-          CALL, /* dist = round(dist) */
+      ELSE,
+        PUSHB_1,
+          bci_round,
+        CALL, /* dist = round(dist) */
 
-        EIF,
       EIF,
+    EIF,
 
-      SWAP, /* s: dist width */
-      PUSHB_1,
-        0,
-      LT, /* width < 0 */
-      IF,
-        NEG, /* dist = -dist */
-      EIF,
+    SWAP, /* s: dist width */
+    PUSHB_1,
+      0,
+    LT, /* width < 0 */
+    IF,
+      NEG, /* dist = -dist */
     EIF,
   EIF,
 
@@ -1027,6 +1026,9 @@ unsigned char FPGM(bci_scale_glyph) [] = {
     bci_scale_contour,
   LOOPCALL,
 
+  PUSHB_1,
+    1,
+  SZP2, /* set zp2 to normal zone 1 */
   IUP_y,
 
   ENDF,
@@ -2432,7 +2434,7 @@ unsigned char FPGM(bci_action_adjust) [] = {
  *
  *        org_pos = anchor + (edge_orig - anchor_orig);
  *        org_center = org_pos + org_len / 2;
-  *
+ *
  *        cur_pos1 = ROUND(org_center)
  *        delta1 = ABS(org_center - (cur_pos1 - u_off))
  *        delta2 = ABS(org_center - (cur_pos1 + d_off))
@@ -4294,6 +4296,9 @@ unsigned char FPGM(bci_hint_glyph) [] = {
     bci_handle_action,
   LOOPCALL,
 
+  PUSHB_1,
+    1,
+  SZP2, /* set zp2 to normal zone 1 */
   IUP_y,
 
   ENDF,
@@ -4477,6 +4482,9 @@ TA_sfnt_build_fpgm_table(SFNT* sfnt,
   if (error)
     return error;
 
+  if (fpgm_len > sfnt->max_instructions)
+    sfnt->max_instructions = fpgm_len;
+
   /* in case of success, `fpgm_buf' gets linked */
   /* and is eventually freed in `TA_font_unload' */
   error = TA_font_add_table(font,
